Installation — Momoko 0.5.0 documentation

### Navigation

- Momoko 0.5.0 documentation »
- index
- / modules
- / next
- / previous

# Installation

Momoko supports Python 2 and 3 (tested with 2.7 and 3.2). PyPy is not supported, because there is no usable Psycopg2 module for PyPy.

Momoko only depends on two modules. Tornado and and Psycopg2 (2.2.0 or higher). Psycopg2 must have support for asynchronous connections.

Momoko can be installed with easy_install or pip:

    pip install momoko

The latest sources can be cloned from the Github repository and installed with:

    python setup.py install

}